Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2006-11-21 16:07:16 +0300
committerTon Roosendaal <ton@blender.org>2006-11-21 16:07:16 +0300
commita9fef5a29237639358fa03888d72e50ad56e5d90 (patch)
treec253c28ccf49cfeb55afd814fe0f6265b9e32351 /source/blender/blenkernel/intern/anim.c
parente75a2773fa2a0a6978ac3c42dd647c6a42751136 (diff)
Bugfix #5270
CurvePaths: if the path has vector handles, or when it's a Poly curve, the amount of interpolated points on the path was too limited (6 actually). Now the 'resolu' of the curve defines the amount of interpolated points. This enables motionpaths or deforming with sharp corners.
Diffstat (limited to 'source/blender/blenkernel/intern/anim.c')
-rw-r--r--source/blender/blenkernel/intern/anim.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenkernel/intern/anim.c b/source/blender/blenkernel/intern/anim.c
index 162cca32b72..88af4da590d 100644
--- a/source/blender/blenkernel/intern/anim.c
+++ b/source/blender/blenkernel/intern/anim.c
@@ -114,8 +114,8 @@ void calc_curvepath(Object *ob)
else tot= bl->nr-1;
path->len= tot+1;
- /* exception: vector handle paths and polygon paths should be subdivided at least a factor 6 (or more?) */
- if(path->len<6*nu->pntsu) path->len= 6*nu->pntsu;
+ /* exception: vector handle paths and polygon paths should be subdivided at least a factor resolu */
+ if(path->len<nu->resolu*nu->pntsu) path->len= nu->resolu*nu->pntsu;
dist= (float *)MEM_mallocN((tot+1)*4, "calcpathdist");